@@ -51,6 +51,8 @@ LSF_init(
     if (!logger)
         return -1;
 
+    logger->sock = -1;
+
     logger->pid = getpid();
 
     logger->linebuf = malloc(logger->bufsize = INITIAL_BUFSIZE);
@@ -155,6 +157,14 @@ LSF_set_receiver(LogSyslogFast* logger, int proto, const char* hostname, int por
     struct addrinfo* results = NULL;
 #endif
 
+    if (logger->sock >= 0) {
+        int ret = close(logger->sock);
+        if (ret) {
+            logger->err = strerror(errno);
+            return -1;
+        }
+    }
+
     /* set up a socket, letting kernel assign local port */
     if (proto == LOG_UDP || proto == LOG_TCP) {
 
@@ -366,3 +376,9 @@ LSF_get_pid(LogSyslogFast* logger)
 {
     return logger->pid;
 }
+
+int
+LSF_get_sock(LogSyslogFast* logger)
+{
+    return logger->sock;
+}
